require 'helper'

describe Store::DataMapper::Memory::HashDupper do

  it 'dups simple string hashes' do
    hash = {
      'a' => "ABC"
    }

    dupped_hash = duplicate(hash)

    dupped_hash['a'].gsub!('A', 'a')

    assert_equal 'ABC', hash['a']
    assert_equal 'aBC', dupped_hash['a']
  end

  it 'dups simple symbol hashes' do
    hash = {
      :a => "ABC"
    }

    dupped_hash = duplicate(hash)

    dupped_hash[:a].gsub!('A', 'a')

    assert_equal 'ABC', hash[:a]
    assert_equal 'aBC', dupped_hash[:a]
  end

  it 'can process symbolic values' do
    hash = {
      'a' => :symbol1
    }

    dupped_hash = duplicate(hash)

    assert_equal :symbol1, dupped_hash['a']
  end

  it 'can process fixnum' do
    hash = {
      'a' => 32
    }

    dupped_hash = duplicate(hash)

    assert_equal 32, dupped_hash['a']
  end

  it 'can process float' do
    hash = {
      'a' => 1.3
    }

    dupped_hash = duplicate(hash)

    assert_equal 1.3, dupped_hash['a']
  end

  it 'can process true' do
    hash = {
      'a' => true
    }

    dupped_hash = duplicate(hash)

    assert_equal true, dupped_hash['a']
  end

  it 'can process false' do
    hash = {
      'a' => false
    }

    dupped_hash = duplicate(hash)

    assert_equal false, dupped_hash['a']
  end


  private
  def duplicate(hash)
    Store::DataMapper::Memory::HashDupper.dup(hash)
  end
end
